#
# spec file for package rescue
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rescue
Version:        1.0.5
Release:        1.4
Summary:        Action Adventure in Space
License:        GPL-3.0-or-later
Group:          Amusements/Games/Strategy/Other
URL:            https://rescue.sourceforge.net/
Source0:        https://downloads.sourceforge.net/%{name}/Rescue_%{version}.zip
Source1:        %{name}.sh
Source2:        %{name}.desktop
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Requires:       jre <= 1.8.0
BuildArch:      noarch

%description
Rescue! Max is an Action Adventure in Space written in java.
It is based on an old mac game called Rescue! by Tom Spreen.

A 2D space real-time, action/strategy game. You are in control of a ship that
you fly around space fighting enemies and making friends on your way.
The main objective is to rescue people from planets and take them to star bases.

%prep
%setup -q -n Rescue

# extract icon
unzip -j Rescue.jar rescue/gui/logo.png

# Convert to unix line end
find -name "*.txt" -print0 -or -name "*.htm" -print0 -or -name "*.css" -print0 \
    -or -name "*.ini" -print0 -or -name "*.xml" -print0 | xargs -0 dos2unix

# Some docs have the DOS line ends
dos2unix ChangeLog.txt gpl.txt todo.txt

%build

%install
# install wrappers
install -Dm 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{name}

# install directories
mkdir -p  %{buildroot}%{_datadir}/%{name}/{help,lib,missions}
for d in help lib missions ; do
    cp -a $d %{buildroot}%{_datadir}/%{name}
done

# install Jar files
install -Dm 0644 *.jar %{buildroot}%{_datadir}/%{name}

# install icon
install -Dm 0644 logo.png %{buildroot}/%{_datadir}/icons/hicolor/32x32/apps/%{name}.png

# install Desktop file
install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop

%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}%{_prefix}

%files
%doc ChangeLog.txt gpl.txt todo.txt
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png

%changelog
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.5:
  * Grasshopper update (2.9) to fix font loading deadlock on startup
* Sat Apr 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.0.4:
  * fix no sun audio crash on startup
  * fix huge fonts on JDK-13 Linux/GTKTheme hi-res screens
  * fix crash on no row selected in keyboard shortcut screen
* Tue Jun 23 2015 nemysis@gmx.ch
- license update: GPL-3.0+ No indication that this is GPL-3.0 (only)
* Tue Jun 23 2015 nemysis@gmx.ch
- Add BuildRequires for hicolor-icon-theme
- Add BuildRoot
* Mon Nov 24 2014 nemysis@gmx.ch
- Change Source0 Web URL
* Mon Nov 24 2014 nemysis@gmx.ch
- Install icon in %%{_datadir}/icons/hicolor/-x-/apps/ instead of
  %%{_datadir}/pixmaps/
* Tue Oct 21 2014 nemysis@gmx.ch
- Remove rescue-rpmlintrc
- Change rescue.desktop
* Sun Oct 19 2014 nemysis@gmx.ch
- Add rescue.desktop and  rescue-rpmlintrc,
  forgotten in previous commit
* Sun Oct 19 2014 nemysis@gmx.ch
- Use %%{_libexecdir} instead of {_datadir}
- Change Group
- Use rescue.desktop instead of Desktop Entry in spec
- Add rescue-rpmlintrc
- Use check for openSUSE %%if 0%%{?suse_version}
- Remove BuildRequires for desktop-file-utils
- Remove not needed mkdir -p
- Change %%fdupes
- Change rescue.sh
* Thu Sep 18 2014 nemysis@gmx.ch
- Initial package creation
